#!/bin/bash
trap '
  trap - INT # restore default INT handler
  kill -s INT "$$"
' INT

JARVERSION=v5
## When changing tag version, also update docker image tag in .gitlab-ci.yml
JARURL="https://git.uark.edu/omniupdate/sysadmin/outransformutils/-/jobs/artifacts/$JARVERSION/file/target/outransformutils-$JARVERSION.jar?job=build"
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )/.." >/dev/null 2>&1 && pwd )"
export CI_COMMIT_REF_SLUG=${CI_COMMIT_REF_SLUG:=$(git rev-parse --abbrev-ref HEAD || echo 'development')}

if [[ `which java` = "" ]]; then
  echo "java is not available, using docker"
  exec docker run --rm -v "${DIR}":/data -e CI_COMMIT_REF_SLUG=${CI_COMMIT_REF_SLUG} registry.git.uark.edu/omniupdate/sysadmin/outransformutils:${JARVERSION} sh/makehtml.sh $@
 fi

if [[ -f /usr/local/bin/outransformutils-1.0-capsule-fat.jar ]]; then
  ## The Jar (@ 1.0-fat) file is baked into the outransformutils Docker image
    JAR=/usr/local/bin/outransformutils-1.0-capsule-fat.jar
elif [[ ! -f ${DIR}/vendor/outransformutils-${JARVERSION}.jar ]]; then
        # User must download the file manually
        mkdir -p ${DIR}/vendor/
        if [[ `which open` ]]; then
          open "${JARURL}"
        elif [[ `which start` ]]; then
          start "${JARURL}"
        elif [[ `which xdg-open` ]]; then
          xdg-open "${JARURL}"
        fi
        echo "Please download the JAR file located here:"
        echo
        echo "${JARURL}"
        echo
        echo "Copy outransformutils-${JARVERSION}.jar to ${DIR}/vendor/ and run this script again."
        echo
        exit 1
else
    JAR=${DIR}/vendor/outransformutils-${JARVERSION}.jar
fi
# pass variables to Saxon with namespaces to match OmniUpdate
# see http://manpages.ubuntu.com/manpages/bionic/man1/saxonb-xslt.1.html

## Build argument list
ARGLIST=({http://omniupdate.com/XSL/Variables}action=ci)
ARGLIST+=({http://omniupdate.com/XSL/Variables}root=$DIR/build/pcf)
if [[ `which git` ]]; then
  ARGLIST+=({http://uark.edu/omniupdate/Variables}email=$(git log -1 --pretty=format:'%ae'))
fi
## EXAMPLE: Add another analytics property for local dev and Review server:
## This is added to window.trackingIds
## ARGLIST+=({http://omniupdate.com/XSL/Variables}analyticsIDs-CSV=UA-xxxx-x)

# -sourceDir is converted to template parameter before being passed to Saxon
java -jar ${JAR} \
	-sourceDir:"${DIR}" \
	-xsl:${DIR}/src/xsl/cicd.xsl \
  -navXsl:${DIR}/src/xsl/cicd.xsl \
	"${ARGLIST[@]}" "$@"
