/*

*** File paths are relative to THIS FILE ***

Imports beginning with ./ are local files
All other imports are node_modules
*/


/*
   Static assets, listed so webpack knows to include them in the bundle.
   If an asset is referenced from JS or CSS, it will be inlined if the size is
   less than the limit in webpack.config.js
*/
import '../sass/uark-base.scss'; // CSS is bundled separately, but must be referenced here

import 'bootstrap'; //side effects, no vars
import './_shared/header.js'; // side effects, no vars
import './_shared/bootstrap-setup.js'; // side effects, no vars
import './_shared/nav-setup.js'; // side effects, no vars

window.UARK = {
  'analytics': {initialized: false},
  'info'     : 'Global namespace object for UARK-specific initialization and libraries.',
  'util'     : {'findNearestHeading': require('./util/findNearestHeading.js')},
  'settings' : Object.assign(
    {'autoAnchor': true },
    window.settings || {}
  ),
};

/*
MAIN INIT
*/
(() => {
    // lazy load analytics code to take advantage of code splitting
    import('./_shared/analytics.js').then((analytics) => {
      window.trackingIds = window.trackingIds || [];
      window.UARK.analytics = analytics.init(window.trackingIds);
    });

    import('./_shared/autoAnchor.js');

    // Initiate all other lazy code paths here...
    if ($('pre code, .force-select').length) {
      import('./_shared/clipboard-setup.js'); // side effects, no vars
      import('./_shared/code-highlighting.js');
    }
    if ($('[data-toggle="hideseek"]').length) {
      // This is so small, it's not neccessary to lazy load, but it's a good example.
      import('./_shared/hideseek-local.js').then((hideseek) =>
        hideseek.init());
    }

})(window);


