<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE stylesheet [
<!ENTITY nbsp   "&#160;">
<!ENTITY copy   "&#169;">
]>
<xsl:stylesheet exclude-result-prefixes="ou xsl xs fn ouc uark util" expand-text="yes" version="3.0"
    xmlns:fn="http://omniupdate.com/XSL/Functions"
    xmlns:ou="http://omniupdate.com/XSL/Variables"
    xmlns:ouc="http://omniupdate.com/XSL/Variables"
    xmlns:uark="http://uark.edu/omniupdate/Variables"
    xmlns:util="http://uark.edu/omniupdate/Utilities"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- Additional XSL Resources -->
  <xsl:import href="variables.xsl"/>
  <xsl:import href="functions.xsl"/>
  <xsl:import href="template-matches.xsl"/>
  <xsl:import href="util.xsl"/>
  <xsl:import href="layouts.xsl"/>
  <xsl:import href="breadcrumbs.xsl"/>
  <xsl:import href="outputs.xsl"/>
  <xsl:import href="social-tags.xsl"/>
  <!-- Default: for HTML5 use below output declaration -->
  <xsl:output encoding="UTF-8" indent="yes" method="html" version="5"/>
  <!-- Begin building the page here -->
  <xsl:template match="/document">
    <html lang="en">
      <head>
        <meta charset="utf-8"/>
        <meta content="IE=edge" http-equiv="X-UA-Compatible"/>
        <meta content="width=device-width, initial-scale=1, shrink-to-fit=no" name="viewport"/>
        <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
        <xsl:copy-of copy-namespaces="no" select="ou:get-title-tag()"/>
        <xsl:if test="$is-pub">
          <link href="{$page-pub-path}" rel="canonical"/>
          <!-- canonical -->
        </xsl:if>
        <xsl:apply-templates select="metadata/ouc:properties/parameter"/>
        <xsl:call-template name="common-headcode"/>
        <!-- common headcode scripts for the <head> -->
        <xsl:apply-templates select="headcode/node()"/>
        <!-- pcf -->
        <!-- <xsl:call-template name="ou-click-tip-css"/> -->
        <!-- css class for click tips -->
        <xsl:call-template name="editor-plugins-css"/>
        <xsl:call-template name="full-social-meta-tag-output"/>
        <!-- social meta tag output -->
      </head>
      <body class="{$bodyclass}">
        <xsl:apply-templates select="bodycode/node()"/>
        <!-- pcf -->
        <nav id="skiptocontent">
          <a href="#skip">Skip to content</a>
        </nav>
        <xsl:call-template name="common-mobile-menu"/>
        <!-- HEADER -->
        <xsl:call-template name="common-header"/>
        <!-- CONTENT -->
        <xsl:call-template name="common-layout"/>
        <!-- FOOTER -->
        <xsl:call-template name="site-footer"/>
        <xsl:call-template name="uark-footer"/>
        <xsl:call-template name="common-footcode"/>
        <!-- common footcode scripts -->
        <xsl:call-template name="direct-edit"/>
        <!-- outputs the direct edit OU Campus object and direct-edit js -->
        <xsl:value-of disable-output-escaping="yes" select="util:getStaticBodyIncludesText()"/>
        <!-- <xsl:call-template name="ou-click-tip-modal"/> -->
        <!-- click tip modal -->
        <xsl:call-template name="editor-plugins-js"/>
        <xsl:apply-templates select="footcode/node()"/>
        <!-- pcf -->
      </body>
    </html>
  </xsl:template>

  <xsl:template expand-text="yes" name="common-headcode">
    <link crossorigin="anonymous" href="https://use.fontawesome.com/releases/v5.5.0/css/all.css" integrity="sha384-B4dIYHKNBt8Bc12p+WXckhzcICo0wtJAoU8YZTY5qE0Id1GSseTk6S+L3BlXeVIU" rel="stylesheet"/>
    <!--
                JavaScript is placed in head with DEFER or ASYNC attribute so network calls can be performed while page is being parsed.
                DEFER maintains execution order, ASYNC will execute in undefined order
                https://flaviocopes.com/javascript-async-defer/#just-tell-me-the-best-way
                -->
    <script crossorigin="anonymous" defer="defer" integrity="sha256-FgpCb/KJQlLNfOu91ta32o/NMZxltwRo8QtmkMRdAu8=" src="https://code.jquery.com/jquery-3.3.1.min.js"/>
    <script crossorigin="anonymous" defer="defer" integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js"/>
    <script crossorigin="anonymous" defer="defer" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"/>
    <xsl:call-template name="util:getAnalyticsTrackingIds"/>
    <script async="async" src="https://www.google-analytics.com/analytics.js"/>
    <xsl:value-of disable-output-escaping="yes" select="util:getStaticHeadIncludesText()"/>
  </xsl:template>

  <!-- Mobile Menu -->
  <!--
 <div class="grid-container">
  <div class="nav-logo"></div>
  <div class="nav-tiers"></div>
  <div class="nav-search"></div>
</div>
 -->
  <xsl:template expand-text="yes" name="common-mobile-menu">
    <div class="navbar-collapse offcanvas-collapse d-block d-md-none" id="uark-mobile-menu">
      <div class="d-flex mb-3 align-items-start" id="mobile-menu-site-id">
        <xsl:if test="$ou:tier2 || $ou:tier3">
          <div class="pr-2 align-self-end" id="uark-site-id-menu">
            <xsl:if test="$ou:tier2">
              <h1 id="uark-t2-menu">
                <a href="{$ou:tier2URL}">
                  <xsl:value-of select="$ou:tier2"/>
                </a>
              </h1>
            </xsl:if>
            <xsl:if test="$ou:tier3">
              <h2 id="uark-t3-menu">
                <a href="{$ou:tier3URL}">
                  <xsl:value-of select="$ou:tier3"/>
                </a>
              </h2>
            </xsl:if>
          </div>
        </xsl:if>
        <div class="ml-auto p-0 border-0">
          <button class="navbar-toggler text-primary" data-toggle="offcanvas" style="width:115px;" type="button">
									CLOSE
            <i aria-hidden="true" class="fas fa-times-circle" style="display:inline;"/>
          </button>
        </div>
      </div>
      <form class="d-flex justify-content-left" id="uark-mobile-search-form">
        <label class="sr-only" for="uark-search-mobile">Search</label>
        <input class="form-control mb-1 mr-sm-1" id="uark-search-mobile" placeholder="Search this site" type="text"/>
        <button class="btn btn-primary mb-1" id="uark-search-button-mobile" type="submit">
          <i aria-hidden="true" class="fas fa-search d-none d-md-block"/>
          <span class="d-xs-inline-block d-lg-none d-xl-inline-block">Search</span>
        </button>
      </form>
      <nav class="card bg-light" id="uark-mobile-topnav" role="navigation">
        <xsl:call-template name="include-main-nav">
          <xsl:with-param name="initial-mode" select="'mobilenav'"/>
        </xsl:call-template>
      </nav>
      <h5 class="text-center mt-3">University of Arkansas Quick Links</h5>
      <div class="d-flex justify-content-center align-items-end">
        <ul id="uark-mobile-quick-links">
          <xsl:call-template name="common-quick-links"/>
        </ul>
        <span>
          <xsl:call-template name="img-from-staticIncludes">
            <xsl:with-param name="filename">assets/tower-grey.5da3823dcdcf3bb2c48715b70ef60575.png</xsl:with-param>
          </xsl:call-template>
        </span>
      </div>
    </div>
  </xsl:template>

  <xsl:template expand-text="yes" name="common-header">
    <header id="uark-header">
      <div id="uark-brand">
        <div class="" id="uark-site-id">
          <div class=" nav-logo">
            <a href="https://uark.edu" id="uark-logo-container">
              <xsl:call-template name="img-from-staticIncludes">
                <xsl:with-param name="filename">
                assets/ua-logo-horz.30f84c1bf004f180c1075895baeb2ac3.svg</xsl:with-param>
                <xsl:with-param name="id">uark-logo</xsl:with-param>
                <xsl:with-param name="alt">University of Arkansas</xsl:with-param>
              </xsl:call-template>
            </a>
          </div>
          <xsl:if test="$ou:tier2 || $ou:tier2Tagline">
            <div class="nav-tiers" id="uark-t2-container">
              <xsl:if test="$ou:tier2">
                <h1 id="uark-t2">
                  <a href="{$ou:tier2URL}">
                    <xsl:value-of select="$ou:tier2"/>
                  </a>
                </h1>
              </xsl:if>
              <xsl:if test="$ou:tier2Tagline">
                <p id="uark-t2-tagline">
                  <xsl:value-of select="$ou:tier2Tagline"/>
                </p>
              </xsl:if>
              <xsl:if test="$ou:tier3">
                <h2 id="uark-t3">
                  <a href="{$ou:tier3URL}">
                    <xsl:value-of select="$ou:tier3"/>
                  </a>
                </h2>
              </xsl:if>
            </div>
          </xsl:if>
          <div class="nav-search ml-auto" id="uark-search-container">
            <form class="form-inline">
              <div id="uark-quick-links-container">
                <a aria-expanded="false" aria-haspopup="true" data-toggle="dropdown" href="#" id="uark-quick-links-button">
                  <i aria-hidden="true" class="fas fa-angle-double-down pr-1"/>
                  <span class="d-xs-inline-block d-md-none d-xl-inline-block">Quick</span>
                  <xsl:text>Links</xsl:text>
                </a>
                <div aria-labelledby="uark-quick-links-button" class="dropdown-menu" id="uark-quick-links-items">
                  <h6 class="text-center">
                    <strong>University of Arkansas</strong>
                  </h6>
                  <div id="uark-quick-links">
                    <ul class="list-group list-group-flush">
                      <xsl:call-template name="common-quick-links"/>
                    </ul>
                  </div>
                </div>
              </div>
              <label class="sr-only" for="uark-search">Search</label>
              <input class="form-control mb-1 mr-sm-1" id="uark-search" placeholder="Search this site" type="text"/>
              <button class="btn btn-primary mb-1" id="uark-search-button" type="submit">
                <i aria-hidden="true" class="fas fa-search"/>
                <!-- <span class="d-xs-inline-block d-lg-none d-xl-inline-block">
                Search</span>-->
              </button>
            </form>
          </div>
          <div class="d-block d-md-none ml-auto mt-2 nav-search" id="mobile-menu-button">
            <button class="navbar-toggler p-0 border-0 text-primary" data-toggle="offcanvas" type="button">
              <span>MENU </span>
              <i aria-hidden="true" class="fas fa-bars"/>
            </button>
          </div>
        </div>
      </div>
      <xsl:if test="ou:layout-param('showTopNav') = 'true'">
        <!-- AKA Main Nav, gray navbar at top -->
        <nav id="uark-site-topnav" role="navigation">
          <xsl:call-template name="include-main-nav">
            <xsl:with-param name="initial-mode" select="'topnav'"/>
          </xsl:call-template>
        </nav>
      </xsl:if>
    </header>
  </xsl:template>

  <xsl:template name="uark-footer">
    <footer id="uark-footer">
      <div class="container">
        <div class="row">
          <div class="col-md-12">
            <h3 class="text-sm-center text-md-left" id="footer-logo">
              <a href="//www.uark.edu" title="University of Arkansas Home Page">UNIVERSITY OF
                 ARKANSAS</a>
            </h3>
            <div class="d-md-flex justify-content-sm-center justify-content-md-between" id="footer-global-links">
              <div>
                <ul class="list-inline text-uppercase text-sm-center text-md-left">
                  <li class="list-inline-item">
                    <a href="https://uark.edu/admissions/index.php" title="University of Arkansas Admissions">Admissions</a>
                  </li>
                  <li class="list-inline-item">
                    <a href="https://www.uark.edu/academics/index.php" title="University of Arkansas Academics">Academics</a>
                  </li>
                  <li class="list-inline-item">
                    <a href="https://uark.edu/campus-life/index.php" title="Campus Life at the University of Arkansas">Campus
                       Life</a>
                  </li>
                  <li class="list-inline-item">
                    <a href="https://uark.edu/research/index.php" title="University of Arkansas Research">Research</a>
                  </li>
                  <li class="list-inline-item">
                    <a href="https://uark.edu/athletics/index.php" title="University of Arkansas Athletics">Athletics</a>
                  </li>
                  <li class="list-inline-item">
                    <a href="https://uark.edu/about/index.php" title="About the University of Arkansas">About</a>
                  </li>
                </ul>
              </div>
              <ul class="list-inline text-sm-center text-md-left" id="social-stack">
                <li class="list-inline-item">
                  <a href="https://www.facebook.com/UofArkansas">
                    <i aria-hidden="true" class="fab fa-lg fa-facebook"/>
                    <span class="sr-only">Like us on Facebook</span>
                  </a>
                </li>
                <li class="list-inline-item">
                  <a href="https://twitter.com/uarkansas">
                    <i aria-hidden="true" class="fab fa-lg fa-twitter"/>
                    <span class="sr-only">Follow us on Twitter</span>
                  </a>
                </li>
                <li class="list-inline-item">
                  <a href="https://www.youtube.com/user/UniversityArkansas">
                    <i aria-hidden="true" class="fab fa-lg fa-youtube"/>
                    <span class="sr-only">Watch us on YouTube</span>
                  </a>
                </li>
                <li class="list-inline-item">
                  <a href="https://instagram.com/uarkansas">
                    <i aria-hidden="true" class="fab fa-lg fa-instagram"/>
                    <span class="sr-only">See us on Instagram</span>
                  </a>
                </li>
                <li class="list-inline-item">
                  <a href="https://pinterest.com/uofaadmissions/">
                    <i aria-hidden="true" class="fab fa-lg fa-pinterest"/>
                    <span class="sr-only">Join us on Pinterest</span>
                  </a>
                </li>
                <li class="list-inline-item">
                  <a href="https://www.linkedin.com/company/university-of-arkansas">
                    <i aria-hidden="true" class="fab fa-lg fa-linkedin"/>
                    <span class="sr-only">Connect with us on LinkedIn</span>
                  </a>
                </li>
              </ul>
            </div>
            <hr/>
            <div class="row">
              <div class="col-sm-6 col-md-3">
                <address>
                  <i aria-hidden="true" class="fas fa-map-marker pull-left fa-lg"/>
									1 University of
                   Arkansas
                  <br/>
									Fayetteville, AR 72701
                  <br/>
									479-575-2000
                </address>
                <a href="https://campusmaps.uark.edu/" title="View Campus Maps">
                  <xsl:call-template name="img-from-staticIncludes">
                    <xsl:with-param name="filename" select="'assets/map.a24152d1af50094d75107d5f0fd0271f.png'"/>
                    <xsl:with-param name="alt" select="'Map of University of Arkansas Campus'"/>
                  </xsl:call-template>
                </a>
              </div>
              <div class="col-sm-6 col-md-3 footer-news">
                <h4>
                  <a href="https://news.uark.edu/" title="Arkansas Newswire">NEWS</a>
                </h4>
                <ul id="news-footer">
                  <li>
                    <a href="https://news.uark.edu/articles/46321">'The Other
                    Mozart' to Be Presented at Faulkner Performing Arts
                    Center</a>
                  </li>
                  <li>
                    <a href="https://news.uark.edu/articles/46283">Stand Up
                    Comedian: Jesus Trejo</a>
                  </li>
                  <li>
                    <a href="https://news.uark.edu/articles/46303">Attend the
                    ASG General Election Debates on Tuesday, Wednesday and
                    Thursday</a>
                  </li>
                </ul>
              </div>
              <div class="col-sm-6 col-md-3 footer-events">
                <h4>
                  <a href="https://calendars.uark.edu/" title="Calendar Events">EVENTS</a>
                </h4>
                <ul id="events-footer">
                  <li>
                    <a href="https://calendars.uark.edu/EventList.aspx?view=EventDetails&amp;eventidn=36106&amp;information_id=84297&amp;type=&amp;rss=rss">
                    Razorback Recovery Meeting (2/25/2019)</a>
                  </li>
                  <li>
                    <a href="https://calendars.uark.edu/EventList.aspx?view=EventDetails&amp;eventidn=36038&amp;information_id=84105&amp;type=&amp;rss=rss">
                    De-stressing Dialogues for International Students
                    (2/25/2019)</a>
                  </li>
                  <li>
                    <a href="https://calendars.uark.edu/EventList.aspx?view=EventDetails&amp;eventidn=36283&amp;information_id=84732&amp;type=&amp;rss=rss">
                    TBP Game Night (2/25/2019)</a>
                  </li>
                </ul>
              </div>
              <div class="col-sm-6 col-md-3 footer-buttons">
                <a class="btn btn-block btn-light btn-lg text-dark text-left" href="https://application.uark.edu/">
                  <i aria-hidden="true" class="fas fa-check fa-lg fa-fw"/>
                  <strong>APPLY</strong>
									Online
                </a>
                <a class="btn btn-block btn-light btn-lg text-dark text-left" href="https://visit.uark.edu/">
                  <i aria-hidden="true" class="fas fa-calendar-alt fa-lg fa-fw"/>
									Schedule a 
                  <strong>VISIT</strong>
                </a>
                <a class="btn btn-block btn-light btn-lg text-dark text-left" href="https://campaign.uark.edu/" id="uark-campaign-btn">
                  <strong>Support</strong>
									Campaign Arkansas
                </a>
              </div>
            </div>
            <hr/>
            <ul class="list-inline text-center footer-disclaimer">
              <li class="list-inline-item">
                <a href="https://emergency.uark.edu/" title="University of Arkansas Emergency Information">
                   Emergency Information</a>
              </li>
              <li class="list-inline-item">
                <a href="https://report.uark.edu/" title="Report a Concern">Report a Concern</a>
              </li>
              <li class="list-inline-item">
                <a href="https://uark.edu/privacy-policy/index.php" title="University of Arkansas Privacy Policy">Privacy
                   Policy</a>
              </li>
              <li class="list-inline-item">
                <a href="https://uark.edu/contact-us.php" title="Contact the University of Arkansas">Contact Us</a>
              </li>
              <li class="list-inline-item">
                <a href="https://jobs.uark.edu" title="Jobs at the University of Arkansas">Jobs</a>
              </li>
              <li class="list-inline-item">
                <a href="https://m.uark.edu" title="Mobile Site">Mobile</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <p class="text-center text-sm py-2">
        <a class="text-light" href="https://uark.edu/">
					©
          <xsl:processing-instruction name="php">echo date('Y');
        ?</xsl:processing-instruction>
					University of Arkansas
        </a>
      </p>
    </footer>
  </xsl:template>

  <xsl:template name="common-footcode"/>
  <xsl:template name="site-footer">
    <div>TODO: include site footer</div>
  </xsl:template>

  <xsl:template name="img-from-staticIncludes">
    <xsl:param name="alt" select="''"/>
    <xsl:param name="id"/>
    <xsl:param name="filename"/>
    <img>
      <xsl:attribute name="alt">
        <xsl:value-of select="$alt"/>
      </xsl:attribute>
      <xsl:if test="$id">
        <xsl:attribute name="id">
          <xsl:value-of select="$id"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:attribute name="src">
        <xsl:value-of select="$uark:staticIncludesBase => normalize-space() || $filename => normalize-space()"/>
      </xsl:attribute>
    </img>
  </xsl:template>

  <xsl:template name="include-main-nav">
    <xsl:param name="initial-mode"/>
    <xsl:if test="doc-available(concat($ou:root, $topNavFile))">
      <xsl:choose>
        <xsl:when test="$ou:action = 'ci' and $ou:advancedNav = 'true'">
          <xsl:apply-templates select="doc(concat($ou:root, $topNavFile))"/>
        </xsl:when>
        <xsl:when test="$ou:action = 'ci' and $initial-mode = 'topnav'">
          <xsl:apply-templates mode="topnav" select="doc(concat($ou:root, $topNavFile))"/>
        </xsl:when>
        <xsl:when test="$ou:action = 'ci' and $initial-mode = 'mobilenav'">
          <xsl:apply-templates mode="mobilenav" select="doc(concat($ou:root, $topNavFile))"/>
        </xsl:when>
        <xsl:when test="$ou:action = 'pub'">
          <xsl:value-of select="ou:include-file(replace($topNavFile, '.pcf', '.php'))"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="ou:include-file($topNavFile)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>

  <xsl:template name="editor-plugins-css">
    <xsl:if test="$is-edt">
      <link href="//cdn.omniupdate.com/select-lists/v1/select-lists.min.css" rel="stylesheet"/>
      <link href="//cdn.omniupdate.com/table-separator/v1/table-separator.css" rel="stylesheet"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="editor-plugins-js">
    <xsl:if test="$is-edt">
      <!-- jQuery 1.5+ is required for Select Lists and Table Separator. Add it here if not already included. -->
      <script defer="defer" src="//cdn.omniupdate.com/select-lists/v1/select-lists.min.js"/>
      <script defer="defer" src="//cdn.omniupdate.com/table-separator/v1/table-separator.js"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="common-quick-links">
    <li>
      <a href="https://www.uark.edu/a-to-z.php">A-Z Index</a>
    </li>
    <li>
      <a href="https://learn.uark.edu">Blackboard Learn</a>
    </li>
    <li>
      <a href="https://campusmaps.uark.edu/">Campus Map</a>
    </li>
    <li>
      <a href="https://UAConnect.uark.edu/">UAConnect</a>
    </li>
    <li>
      <a href="https://directory.uark.edu/">Directory</a>
    </li>
    <li>
      <a href="https://email.uark.edu/">UARK Gmail</a>
    </li>
    <li>
      <a href="https://outlook.office.com">Exchange Mail</a>
    </li>
    <li>
      <a href="https://webbasis.uark.edu/">webBASIS</a>
    </li>
  </xsl:template>

  <xsl:template name="common-leftnav">
    <!-- We are already inside a nav element -->
    <xsl:call-template name="output-navigation">
      <!-- <xsl:with-param name="kind" select="'php'"/> -->
      <xsl:with-param name="debug" select="true()"/>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
