<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet exclude-result-prefixes="ou xsl xs fn ouc uark" expand-text="yes" version="3.0"
    xmlns:fn="http://omniupdate.com/XSL/Functions"
    xmlns:ou="http://omniupdate.com/XSL/Variables"
    xmlns:ouc="http://omniupdate.com/XSL/Variables"
    xmlns:uark="http://uark.edu/omniupdate/Variables"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:strip-space elements="navigation ouc:div ouc:editor"/>
  <xsl:preserve-space elements="ul li div a"/>
  <xsl:mode name="topnav" on-no-match="shallow-copy"/>
  <xsl:mode name="mobilenav" on-no-match="shallow-copy"/>
  <xsl:mode name="dropdown" on-no-match="shallow-copy"/>
  <xsl:mode name="dropdown-trigger" on-no-match="deep-skip"/>
  <xsl:mode name="dropdown-builder" on-no-match="deep-skip"/>
  <xsl:mode name="collapse-trigger" on-no-match="deep-skip"/>
  <xsl:mode name="collapse-builder" on-no-match="deep-skip"/>
  <xsl:mode name="uark-nav-link" on-no-match="shallow-copy"/>
  <xsl:template match="/navigation | ouc:div | ouc:editor" mode="#all">
    <xsl:apply-templates mode="#current" select="node()"/>
  </xsl:template>

  <xsl:template match="ul[li[ul[li[ul]]]]" mode="topnav mobilenav" priority="10">
    <p class="alert alert-warning" role="alert">
			Three-level navigation is not supported. For advanced
       navigation features, turn on the
      <a href="https://omniupdate.git-pages.uark.edu/uark-temlates/ou/directory-variables.html#advancedNav')">
    &quot;advancedNav&quot; site variable</a>
			.
    </p>
  </xsl:template>

  <xsl:template match="ul" mode="topnav mobilenav">
    <ul>
      <li class="nav-item nav-item-home">
        <a class="never-selected" href="../">
          <i class="fas fa-home"/>
          <span class="d-inline-block d-md-none">
            <xsl:choose>
              <xsl:when test="$ou:tier3">
                {$ou:tier3}
              </xsl:when>
              <xsl:otherwise>
                 {$ou:tier2}
              </xsl:otherwise>
            </xsl:choose>
          </span>
        </a>
      </li>
      <xsl:apply-templates mode="#current" select="attribute()|node()"/>
    </ul>
  </xsl:template>

  <xsl:template match="li" mode="topnav mobilenav">
    <li class="nav-item">
      <xsl:apply-templates mode="#current" select="attribute()|node()"/>
    </li>
  </xsl:template>

  <xsl:template match="li[ul|processing-instruction()]" mode="topnav">
    <li class="dropdown nav-item">
      <xsl:apply-templates mode="dropdown-trigger" select="node()[not(processing-instruction())]"/>
      <xsl:apply-templates mode="dropdown-builder" select="node()[not(processing-instruction())]"/>
      <xsl:apply-templates mode="dropdown-builder" select="processing-instruction('filelist')"/>
    </li>
  </xsl:template>

  <xsl:template match="li[ul]" mode="mobilenav">
    <li class="nav-item">
      <xsl:apply-templates mode="collapse-trigger" select="node()"/>
      <xsl:apply-templates mode="collapse-builder" select="node()"/>
    </li>
  </xsl:template>

  <xsl:template match="a" mode="collapse-trigger">
    <a aria-expanded="false" aria-haspopup="true" data-toggle="collapse" href="#" role="button">
      <xsl:attribute name="class" select="'uark-nav-link collapsed ' || @class"/>
      <xsl:attribute name="id" select="'mobile' || generate-id(.)"/>
      <xsl:attribute name="aria-controls" select="'collapse' || generate-id(../ul)"/>
      <xsl:attribute name="data-target" select="'#collapse' || generate-id(../ul) || generate-id(../processing-instruction('filelist'))"/>
      <xsl:apply-templates mode="mobilenav" select="attribute()[not(name() = 'href')]|node()"/>
      <xsl:text> </xsl:text>
      <i aria-hidden="true" class="fas fa-caret-down"/>
    </a>
  </xsl:template>

  <xsl:template match="ul" mode="collapse-builder">
    <ul class="collapse">
      <xsl:attribute name="id" select="'collapse' || generate-id(.)"/>
      <xsl:attribute name="aria-labelledby" select="'mobile' || generate-id(../a)"/>
      <xsl:apply-templates mode="collapse-builder" select="node()"/>
    </ul>
  </xsl:template>

  <xsl:template match="li" mode="collapse-builder">
    <li>
      <xsl:apply-templates/>
    </li>
  </xsl:template>

  <xsl:template match="a" mode="topnav mobilenav uark-nav-link">
    <a>
      <xsl:attribute name="class" select="'uark-nav-link ' || @class"/>
      <xsl:apply-templates mode="#current" select="attribute()[not(@class)]|node()"/>
    </a>
  </xsl:template>

  <xsl:template match="a" mode="dropdown-trigger">
    <a aria-expanded="false" aria-haspopup="true" data-boundary="viewport" data-toggle="dropdown" role="button">
      <xsl:attribute name="class" select="'dropdown-toggle uark-nav-link ' || @class"/>
      <xsl:attribute name="id">
        <xsl:value-of select="generate-id(.)"/>
      </xsl:attribute>
      <xsl:apply-templates mode="topnav" select="attribute()|node()"/>
    </a>
  </xsl:template>

  <xsl:template match="ul" mode="dropdown-builder">
    <div class="dropdown-menu uark-topnav-dropdown">
      <xsl:attribute name="aria-labelledby">
        <xsl:value-of select="generate-id(../a)"/>
      </xsl:attribute>
      <xsl:apply-templates mode="dropdown-builder" select="node()"/>
    </div>
  </xsl:template>

  <xsl:template match="li" mode="dropdown-builder">
    <xsl:apply-templates mode="uark-nav-link"/>
  </xsl:template>

</xsl:stylesheet>
