<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE stylesheet [
<!ENTITY amp   "&#38;">
<!ENTITY copy   "&#169;">
<!ENTITY gt   "&#62;">
<!ENTITY hellip "&#8230;">
<!ENTITY laquo  "&#171;">
<!ENTITY lsaquo   "&#8249;">
<!ENTITY lsquo   "&#8216;">
<!ENTITY lt   "&#60;">
<!ENTITY nbsp   "&#160;">
<!ENTITY quot   "&#34;">
<!ENTITY raquo  "&#187;">
<!ENTITY rsaquo   "&#8250;">
<!ENTITY rsquo   "&#8217;">
<!ENTITY times   "&#215;">
]>
<!--
Implementations Skeleton - 01/10/2017
STANDARD TEMPLATE MATCHES
Identity templates that recursively copies all content, or applies other applicable templates.
Contributors: Your Name Here
Last Updated: Enter Date Here
-->
<xsl:stylesheet exclude-result-prefixes="xs ou fn ouc util uark" expand-text="yes" version="3.0"
    xmlns:fn="http://omniupdate.com/XSL/Functions"
    xmlns:ou="http://omniupdate.com/XSL/Variables"
    xmlns:ouc="http://omniupdate.com/XSL/Variables"
    xmlns:uark="http://uark.edu/omniupdate/Variables"
    xmlns:util="http://uark.edu/omniupdate/Utilities"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- Identity Matches -->
  <!-- The following mode will match all items except processing instructions, copies them, then processes any children. -->
  <xsl:mode name="copy" on-no-match="shallow-copy"/>
  <xsl:mode name="variableListing" on-no-match="deep-skip"/>
  <xsl:mode on-no-match="shallow-copy"/>
  <!-- match the pcf-sheet to make the editable region function -->
  <xsl:template match="processing-instruction('pcf-stylesheet')" mode="#all"/>
  <!-- MISC -->
  <!-- don't output ouc tags on publish. -->
  <xsl:template match="ouc:*[$ou:action !='edt']" mode="#all">
    <xsl:apply-templates/>
  </xsl:template>

  <!-- Visual warning for broken dependencies tags -->
  <xsl:template match="a[contains(@href,'*** Broken')]" mode="#all">
    <a href="{@href}" style="color: red; background-color: black; padding: 0 1em;">
      <xsl:value-of select="."/>
    </a>
    <xsl:text> </xsl:text>
    <span class="badge badge-danger">BROKEN LINK</span>
  </xsl:template>

  <!-- The following template matches processing instructions, outputs the proper syntax with the code escaped properly. -->
  <!-- Remove closing '?' mark if not HTML5 output. -->
  <xsl:template match="processing-instruction('php')" mode="#all">
    <xsl:choose>
      <xsl:when test="$ou:action = 'pub'">
        <xsl:processing-instruction name="php">
          <xsl:value-of disable-output-escaping="yes" select="."/>
					?
        </xsl:processing-instruction>
      </xsl:when>
      <xsl:otherwise>
        <i aria-hidden="true" class="fab fa-php"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="meta[not(@content)]">
    <meta content="{text() => normalize-space()}" name="{@name}"/>
  </xsl:template>

  <xsl:template match="parameter[@name='Description']">
    <meta content="{text() => normalize-space()}" name="Description"/>
  </xsl:template>

  <!-- Automatically add styles to Links to Documents -->
  <xsl:template match="a[@href => ends-with('.pdf') or @href => ends-with('.docx') or ends-with(@href,'.xlsx')]">
    <a class="document {@class}">
      <xsl:apply-templates select="attribute()[not(name()='class')]|node()"/>
      <xsl:text> </xsl:text>
      <span class="fas fa-file"/>
    </a>
  </xsl:template>

  <xsl:template match="span[@style => contains('text-decoration: underline;')][$ou:action = 'edt']">
    <span class="badge badge-danger">Don't Underline!</span>
    <xsl:copy>
      <xsl:apply-templates select="attribute()|node()"/>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="img">
    <!-- Add warning to images without alt text -->
    <xsl:if test="not(@alt) or @alt='' and not($ou:action = 'pub')">
      <span class="badge badge-danger">Add Alt Text!</span>
    </xsl:if>
    <!-- Responsive Images by default -->
    <img class="{@class}{if (not(@class => contains('no-responsive'))) then ' img-fluid' else ''}">
      <xsl:apply-templates select="attribute()[not(name() = 'class')]"/>
    </img>
  </xsl:template>

  <!-- Wrap Media Objects with Responsive Container -->
  <xsl:template match="iframe|embed|video">
    <div class="embed-responsive embed-responsive-16by9">
      <xsl:element name="{name()}">
        <xsl:attribute name="class" select="@class || ' embed-responsive-item'"/>
        <xsl:apply-templates select="attribute()|node()"/>
      </xsl:element>
    </div>
  </xsl:template>

  <!-- Progess Bar Widget -->
  <xsl:template match="table[@class='ou-progressbar']">
    <xsl:variable name="percent" select="tbody/tr[1]/td[1] => replace('[^0-9.]', '')"/>
    <div class="progress">
      <div aria-valuemax="100" aria-valuemin="0" aria-valuenow="{$percent}" class="progress-bar" role="progressbar" style="width: {$percent}%;">{$percent}%</div>
    </div>
  </xsl:template>

  <!-- Modals Widget -->
  <xsl:template match="table[@class='modal']">
    <xsl:variable name="trigger" select="tr[1]/td[1]"/>
    <xsl:variable name="title" select="tr[2]/td[1]"/>
    <xsl:variable name="content" select="tr[3]/td[1]"/>
    <xsl:variable name="buttons" select="tr[4]/td[1]"/>
    <xsl:variable name="mID" select="generate-id(.)"/>
    <xsl:choose>
      <xsl:when test="$ou:action = 'edt'">
        <table>
          <thead>
            <tr>
              <th>Table Transformation: Modal</th>
            </tr>
          </thead>
          <xsl:apply-templates/>
        </table>
      </xsl:when>
      <xsl:otherwise>
        <button class="btn btn-primary" data-target="#{$mID}" data-toggle="modal" type="button">{$trigger}</button>
        <div aria-hidden="true" aria-labelledby="{generate-id($title)}" class="modal fade" id="{$mID}" role="dialog" tabindex="-1">
          <div class="modal-dialog" role="document">
            <div class="modal-content">
              <div class="modal-header">
                <h5 class="modal-title" id="{generate-id($title)}">{$title}</h5>
                <button aria-label="Close" class="close" data-dismiss="modal" type="button">
                  <span aria-hidden="true">×</span>
                </button>
              </div>
              <div class="modal-body">
                <xsl:apply-templates select="$content"/>
              </div>
              <div class="modal-footer">
                <xsl:apply-templates mode="buttonize" select="$buttons"/>
                <button class="btn btn-secondary" data-dismiss="modal" type="button">Close</button>
              </div>
            </div>
          </div>
        </div>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="a" mode="buttonize">
    <a class="btn btn-primary {@class}">
      <xsl:apply-templates select="node()|attribute()[not(name()='class')]"/>
    </a>
  </xsl:template>

  <xsl:template match="h1[not(@id)] | h2[not(@id)] | h3[not(@id)] | h4[not(@id)] | h5[not(@id)] | h6[not(@id)]">
    <xsl:element name="{local-name()}">
      <xsl:attribute name="id" select="normalize-space(.) => util:slugify()"/>
      <xsl:apply-templates select="node()|attribute()[not(name() = 'id')]"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="processing-instruction('generateToC')">
    <xsl:call-template name="util:generateToC">
      <xsl:with-param name="nodes" select="//h1|//h2|//h3"/>
      <xsl:with-param name="tag" select="if (. => contains('ul')) then 'ul' else 'ol'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="processing-instruction('filelist')" mode="#all">
    <xsl:variable name="path" select=". => normalize-space()"/>
    <xsl:variable name="nodes">
      <ul>
        <xsl:for-each select="collection(concat($ou:root, '/', $path, '/?select=*.pcf;recurse=no'))">
          <xsl:sort select="."/>
          <xsl:variable name="doc" select="."/>
          <xsl:variable name="title" select="$doc/document/metadata/ouc:properties/title"/>
          <xsl:variable name="href" select="document-uri(.) => replace('file:' || $ou:root, '') => replace('.pcf', '.html')"/>
          <li>
            <a href="{$href}">{$title}</a>
          </li>
        </xsl:for-each>
      </ul>
    </xsl:variable>
    <xsl:apply-templates mode="#current" select="$nodes"/>
  </xsl:template>

  <!--  Outlines -->
  <xsl:template match="ol[ol]">
    <ol class="outline {@class}">
      <xsl:apply-templates select="node()|attribute()[not(name()='class')]"/>
    </ol>
  </xsl:template>

  <xsl:template match="@href" mode="#all">
    <xsl:attribute name="href">{uark:fix-href-for-ci(.)}</xsl:attribute>
  </xsl:template>

  <!-- Add noopener to any link opening in "_blank" -->
  <xsl:template match="@target" mode="#all">
    <xsl:copy-of select="."/>
    <xsl:if test=". = '_blank'">
      <xsl:attribute name="rel">noopener noreferrer</xsl:attribute>
    </xsl:if>
  </xsl:template>

  <xsl:template match="maincontent | secondarycontent">
    <xsl:apply-templates select="node()"/>
  </xsl:template>

</xsl:stylesheet>
