<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE stylesheet [
<!ENTITY nbsp   "&#160;">
]>
<xsl:stylesheet exclude-result-prefixes="ou xsl xs fn ouc uark util" expand-text="yes" version="3.0"
    xmlns:fn="http://omniupdate.com/XSL/Functions"
    xmlns:ou="http://omniupdate.com/XSL/Variables"
    xmlns:ouc="http://omniupdate.com/XSL/Variables"
    xmlns:uark="http://uark.edu/omniupdate/Variables"
    xmlns:util="http://uark.edu/omniupdate/Utilities"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template name="util:getAnalyticsTrackingIds">
    <xsl:variable name="propertyIDs" select="tokenize(concat( util:getDefaultTrackingIds(), ',', $ou:analyticsIDs-CSV),',')"/>
    <script>
      <!--
            Add event listener for global error tracking
            You won't be able to see it working in Chrome inspector, unless you use setTimeout(function() { notThere(); }, 0);
        -->
      <xsl:text>
        window.addEventListener('error', window.__e=function f(e){{f.q=f.q||[];
        f.q.push(e)}});
        window.trackingIds=window.trackingIds||[];
      </xsl:text>
      <xsl:for-each select="$propertyIDs">
        <xsl:if test=". != ''">
          <xsl:text>window.trackingIds.push(&quot;{normalize-space(.)}&quot;);</xsl:text>
        </xsl:if>
      </xsl:for-each>
    </script>
  </xsl:template>

  <xsl:function name="util:getDefaultTrackingIds">
    <xsl:choose>
      <xsl:when test="$ou:action = 'pub'">
        <!-- Legacy UARK GA property that is included on ALL subdomains -->
        <xsl:text>UA-127684-2</xsl:text>
      </xsl:when>
      <xsl:when test="$ou:action = 'ci'">
        <!-- ITS sub-property that tracks clicks in dev environments -->
        <xsl:text>UA-18311705-26</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <!-- No tracking inside OU in preview/edit -->
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <xsl:function name="util:slugify">
    <xsl:param name="text"/>
    <xsl:text>{
      $text =>
      lower-case() =>
      replace('[^a-z0-9]','-') =>
      replace('[-]+','-') =>
      replace('-$', '') =>
      replace('^-', '')
      }</xsl:text>
  </xsl:function>

  <xsl:template name="util:generateToC">
    <xsl:param name="nodes"/>
    <xsl:param name="level" select="1"/>
    <xsl:param name="tag" select="'ol'"/>
    <xsl:element name="{$tag}">
      <xsl:attribute name="class" select="if ($level = 1) then 'outline' else ''"/>
      <xsl:for-each-group group-starting-with="*[local-name() = 'h' || $level]" select="$nodes">
        <xsl:variable name="heading-id">{if (@id) then @id else
        util:slugify(.)}</xsl:variable>
        <li>
          <a href="#{$heading-id}">
            <xsl:value-of select="."/>
          </a>
          <xsl:if test="current-group()[2]">
            <xsl:call-template name="util:generateToC">
              <xsl:with-param name="nodes" select="current-group() except ."/>
              <xsl:with-param name="level" select="$level + 1"/>
              <xsl:with-param name="tag" select="$tag"/>
            </xsl:call-template>
          </xsl:if>
        </li>
      </xsl:for-each-group>
    </xsl:element>
  </xsl:template>

  <!-- ## STATIC INCLUDES
                There is a bug in the webpack plugin that injects <link> and <script> tags.
                It only outputs html5, not xhtml, so we have to grab the text directly
                instead of transforming the elements.
        -->
  <xsl:function name="util:getStaticIncludesText">
    <xsl:text>{
    if ($ou:action = 'ci')
      (: In CI environment, the webpack output is in
          a different directory  :)
      then unparsed-text('../../public/statics.html')
    else
      unparsed-text('../statics.html')
    }</xsl:text>
  </xsl:function>

  <xsl:function name="util:getStaticHeadIncludesText">
    <xsl:try>
      <xsl:value-of disable-output-escaping="yes" select="util:getStaticIncludesText() => substring-after('&lt;head&gt;') => substring-before('&lt;/head&gt;')"/>
      <xsl:catch>
        <xsl:text disable-output-escaping="yes">&lt;!-- Could not read static includes file. This is expected when using 'npm start'. --&gt;</xsl:text>
      </xsl:catch>
    </xsl:try>
  </xsl:function>

  <xsl:function name="util:getStaticBodyIncludesText">
    <xsl:try>
      <xsl:value-of disable-output-escaping="yes" select="util:getStaticIncludesText() => substring-after('&lt;body&gt;') => substring-before('&lt;/body&gt;')"/>
      <xsl:catch>
        <xsl:text disable-output-escaping="yes">&lt;!-- Could not read static includes file. This is expected when using 'npm start'. --&gt;</xsl:text>
      </xsl:catch>
    </xsl:try>
  </xsl:function>

  <xsl:template name="util:cicd-banner">
    <xsl:if test="$ou:action = 'ci'">
      <p class="alert alert-info mt-3" role="alert">
        This page was generated by an automated build system. The latest commit in this directory was created by: {$uark:email}
      </p>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
