<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE stylesheet>
<xsl:stylesheet exclude-result-prefixes="ou xsl xs fn ouc uark" expand-text="yes" version="3.0"
    xmlns:fn="http://omniupdate.com/XSL/Functions"
    xmlns:ou="http://omniupdate.com/XSL/Variables"
    xmlns:ouc="http://omniupdate.com/XSL/Variables"
    xmlns:uark="http://uark.edu/omniupdate/Variables"
    xmlns:util="http://uark.edu/omniupdate/Utilities"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- This is a stub file. DO NOT EDIT. -->
  <!-- In CI/CD environment, cicd.xsl is called. In OmniUpdate, page.xsl is the starting point for pages. -->
  <xsl:param name="uark:path"/>
  <!-- Import resource XSL files here -->
  <xsl:import href="_shared/common.xsl"/>
  <xsl:import href="_shared/nav-matches.xsl"/>
  <!-- SPECIAL -->
  <xsl:template match="util:directoryvariablelisting">
    <xsl:apply-templates/>
    <xsl:apply-templates mode="variableListing" select="doc('_shared/variables.xsl')/xsl:stylesheet"/>
  </xsl:template>

  <xsl:template match="/xsl:stylesheet" mode="variableListing">
    <xsl:apply-templates mode="variableListing" select="comment()"/>
  </xsl:template>

  <xsl:template match="comment()" mode="variableListing">
    <xsl:variable name="lines" select=". => replace('^[\s]+', '') => tokenize('\n')"/>
    <xsl:variable name="headline" select="normalize-space($lines[1])"/>
    <xsl:variable name="hasParam" select="(following-sibling::*|following-sibling::comment())[1][self::xsl:param]"/>
    <xsl:variable name="hasVar" select="following-sibling::*[2][self::xsl:variable]"/>
    <xsl:choose>
      <xsl:when test="$headline => starts-with('##')">
        <h2>
          <xsl:attribute name="id" select="$lines[1] => replace('##', '') => normalize-space() => util:slugify()"/>
                    {normalize-space(replace($lines[1], '##',
        ''))}
        </h2>
        <p>
          <xsl:value-of disable-output-escaping="yes" select="ou:nl2br($lines[position() &gt; 1])"/>
        </p>
      </xsl:when>
      <xsl:when test="$headline => starts-with( $hasParam => replace( 'ou:', '') )">
        <h3 class="variable-name h4">
          <xsl:attribute name="id" select="$lines[1] => normalize-space() => util:slugify()"/>
                    {normalize-space($lines[1])}
        </h3>
        <p>
          <xsl:value-of disable-output-escaping="yes" select="$lines[position() &gt; 1] => ou:nl2br()"/>
        </p>
      </xsl:when>
      <xsl:otherwise>
        <p>
          <xsl:value-of disable-output-escaping="yes" select="$lines => ou:nl2br()"/>
        </p>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates mode="variableListing" select="$hasParam"/>
  </xsl:template>

  <xsl:template match="xsl:param" mode="variableListing">
    <xsl:variable name="varNode" select="following-sibling::*[1][self::xsl:variable]"/>
    <xsl:variable name="varName" select="$varNode/@name"/>
    <xsl:variable name="varSelect" select="$varNode/@select"/>
    <xsl:if test="@select">
      <p class="highlight">
        <strong>Default</strong>
        <xsl:text>: {@select}</xsl:text>
      </p>
    </xsl:if>
    <pre>
      <code class="language-xml">
        <xsl:apply-templates mode="serialize" select="."/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates mode="serialize" select="$varNode"/>
      </code>
    </pre>
  </xsl:template>

  <xsl:template match="*" mode="serialize">
    <xsl:text>&lt;{name(.)}</xsl:text>
    <xsl:apply-templates mode="serialize" select="attribute()"/>
    <xsl:choose>
      <xsl:when test="node()|text()">
        <xsl:text>&gt;</xsl:text>
        <xsl:apply-templates mode="serialize" select="node()|text()"/>
        <xsl:text>&lt;/{name(.)}&gt;</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>/&gt;</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text()" mode="serialize">
    <xsl:text>{.}</xsl:text>
  </xsl:template>

  <xsl:template match="attribute()" mode="serialize">
    <xsl:text> {name(.)}=&quot;{.}&quot;</xsl:text>
  </xsl:template>

</xsl:stylesheet>
